@@ -41,7 +41,7 @@
 
 #define IFCONFIG "/sbin/ifconfig "
 #define IP_COMMAND " | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}'"
-#define INTERFACE_COMMAND "/sbin/route -n | grep \"UG\" | awk '{print $8}'"
+#define INTERFACE_COMMAND "/sbin/route -n | awk '$1 == \"0.0.0.0\" {print $8}'"
 
 #define _(String) dgettext("hildon-libs", String)
 
@@ -199,26 +199,27 @@ gboolean personal_ip_address_update_content (PersonalIpAddress *self)
 	fp = popen (INTERFACE_COMMAND, "r");
 	
 	while (fgets (line, sizeof line, fp)) {
-		interface = g_strstrip (g_strdup_printf ("%s", line));
+		interface = g_strstrip (line);
 		gtk_label_set_text (GTK_LABEL (self->priv->interfaceContent), interface);
-		if (g_strcasecmp (interface, "") != 0) {
+		if (!g_str_equal (interface, "")) {
 			found = TRUE;
+			break;
 		}
 	}
 	pclose (fp);
 	
 	if (found) {
+		gchar *cmd = g_strconcat (IFCONFIG, interface, IP_COMMAND, NULL);
 		found = FALSE;
-		fp = popen (g_strconcat (IFCONFIG, interface, IP_COMMAND, NULL) , "r");
+		fp = popen (cmd, "r");
 		
 		while (fgets (line, sizeof line, fp)) {
-			gchar *gline = g_strdup_printf ("%s", line);
-			gtk_label_set_text (GTK_LABEL (self->priv->ipContent), g_strstrip (gline));
+			gtk_label_set_text (GTK_LABEL (self->priv->ipContent), g_strstrip (line));
 			found = TRUE;
-			g_free (gline);
-			g_free (interface);
+			break;
 		}
 		pclose (fp);
+		g_free (cmd);
 	}
 	
 	if (!found) {
